@@ -1,9 +1,8 @@
 
 # test diversities table -------------------------------------------------------
 context("individual_pathotypes()")
-Ps <- system.file("extdata", "practice_data_set.csv", package = "hagis")
-Ps <- read.csv(Ps)
-diversities <- calculate_diversities(x = Ps,
+data(P_sojae_survey)
+diversities <- calculate_diversities(x = P_sojae_survey,
                                      cutoff = 60,
                                      control = "susceptible",
                                      sample = "Isolate",
